// Anaconda mode
#storage.storage-anaconda {
  .pf-v6-c-page__main-container {
    border-radius: 0;
    margin: 0;
    border: 0;
    max-block-size: 100%;
  }

  .pf-v6-c-page__main {
    padding-inline: var(--pf-t--global--spacer--gap--group-to-group--vertical--default);
  }

  .pf-v6-c-page {
    --pf-v6-c-page--BackgroundColor: var(--pf-t--global--background--color--primary--default);
  }

  .pf-v6-c-card {
    --pf-v6-c-card--BorderColor: transparent;
  }
}
