@import "gtk-doc.css";

/* keep this in sync with node_modules/@redhat/redhat-font/webfonts/red-hat-font.css */
@font-face {
  font-family: RedHatText;
  src: url("./RedHatText-Regular.woff2") format("woff2");
  /* Modern Browsers */
  font-style: normal;
  font-weight: 400;
  text-rendering: optimizelegibility;
}

@font-face {
  font-family: RedHatText;
  src: url("./RedHatText-Medium.woff2") format("woff2");
  /* Modern Browsers */
  font-style: normal;
  font-weight: 700;
  text-rendering: optimizelegibility;
}

h1.guides {
	background-color: #238b49;
	color: white;
	font-family: Georgia, "Times New Roman", Times, serif;
	font-size: 30pt;
	padding-block: 5px;
	padding-inline: 20px 0;
}

h2.guides {
    margin-inline-start: 20px;
}

div.guides {
	margin-inline: 20px;
	font-family: RedHatText, Verdana, Arial, 'Bitstream Vera Sans', Helvetica, sans-serif;
	font-size: 11pt;
}

div.guides > p {
    margin-inline-start: 20px;
}

div.guides > a {
	margin-inline: 40px 20px;
	font-size: 12px;
	line-height: 200%;
        display: block;
}

table.navigation {
	background-color: #238b49 !important;
	border-width: 0 !important;
	color: white;
	font-family: Georgia, "Times New Roman", Times, serif;
}

table.navigation th {
	font-size: 30pt !important;
	font-weight: normal;
	text-align: start !important;
	padding-inline-start: 10pt;
}

table.navigation th:first-child {
	padding-block: 5px;
	padding-inline: 20px 0;
}

.shortcuts {
	color: white !important;
}

.shortcuts a {
	color: white !important;
	font-family: RedHatText, Verdana, Arial, 'Bitstream Vera Sans', Helvetica, sans-serif;
}

p.title {
	font-size: 30pt !important;
}

div.warning {
    padding: 15px;
}

.warning .title {
	font-weight: bold !important;
	inset-inline-start: 0;
}

body {
	padding-block-start: 5.5em !important;
	margin: 0;
}


/* Target all Firefox, since firefox has bug wrt TABLE + position: fixed */
/* stylelint-disable-next-line at-rule-no-vendor-prefix */
@-moz-document url-prefix() {
	table.navigation { position: static !important; }
	body { padding-block-start: 0 !important; }
}

p.releaseinfo {
	margin: 1em;
}

div.toc {
	margin: 1em;
}

div.book,
div.refentry,
div.chapter,
div.article,
div.reference,
div.index,
div.footer,
div.section,
div.part {
	font-family: RedHatText, Verdana, Arial, 'Bitstream Vera Sans', Helvetica, sans-serif;
	font-size: 11pt;
	line-height: 160%;
}

code {
    font-size: 10.5pt;
}

body > div.footer,
body > div.part {
	margin-inline: 1em;
}

body > div.refentry,
body > div.chapter,
body > div.article,
body > div.reference,
body > div.index,
body > div.section,
body > div.part,
body > div.book > div.toc {
    padding-block-start: 50px;
    max-inline-size: 800px;
    padding-inline: 40px 20px;
    margin-inline: auto;
    /*
	margin-left: 3em;
	margin-right: 1em;
        */
}

body > div.book > div.toc {
    padding-block-start: 20px;
}

div.section {
	margin-block-start: 3em;
}

pre.programlisting {
    font-size: 9.5pt;
    line-height: 130%;
    padding-inline-start: 10px;
}

div.variablelist table {
	font-size: 13pt;
	line-height: 150%;
        margin-inline-start: 0;
}

div.variablelist table span.term {
	padding-inline-end: 1em;
}

div.variablelist {
    margin-inline-start: 0;
}

div.refsect1,
div.refsect2,
div.refsection,
div.refnamediv,
div.refsynopsisdiv {
	margin-block-end: 2em !important;
}

div.refsection > h3 {
	margin-block-start: 1.5em !important;
}

div.abstract > .title {
	margin: 0.3em;
	visibility: hidden;
}

h1 {
	font-weight: normal !important;
}

h2 {
	position: relative;
	inset-inline-start: -1em;
	font-weight: normal !important;
}

h3 {
	position: relative;
	inset-inline-start: -1em;
	font-weight: normal !important;
}

dd > dl {
	margin-block: 0.3em;
}

pre.screen {
	border: solid 1px #729fcf;
	padding: 0.5em;
	background: #e6f3ff;
}

code.option {
	white-space: nowrap;
}
