/*
 * This file is part of Cockpit.
 *
 * Copyright (C) 2016 Red Hat, Inc.
 *
 * Cockpit is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * Cockpit is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Cockpit; If not, see <https://www.gnu.org/licenses/>.
 */

@use "ct-card";
@use "page";

#app .pf-v6-c-card {
  @extend .ct-card;
}

.setroubleshoot-log {
  font-family: monospace;
}

.setroubleshoot-progress-spinner {
  display: inline-block;
}

.setroubleshoot-progress-message {
  vertical-align: top;
}

.selinux-details {
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  gap: var(--pf-t--global--spacer--sm) var(--pf-t--global--spacer--md);

  > div:first-child {
    inline-size: 70%;
    flex: auto;
  }

  + hr {
    margin-block-start: var(--pf-t--global--spacer--sm);
  }

  .pf-v6-c-expandable-section__content {
    margin-block-start: unset;
  }
}

.selinux-details textarea {
  margin-block-start: var(--pf-t--global--spacer--xs);
  resize: none;
}
